@@ -1,6 +1,6 @@
 package WWW::AdventCalendar;
 # ABSTRACT: a calendar for a month of articles (on the web)
-$WWW::AdventCalendar::VERSION = '1.111';
+$WWW::AdventCalendar::VERSION = '1.112';
 use Moose;
 
 use MooseX::StrictConstructor;
@@ -26,117 +26,117 @@ use XML::Atom::SimpleFeed;
 
 use namespace::autoclean;
 
-# =head1 DESCRIPTION
-#
-# This is a library for producing Advent calendar websites.  In other words, it
-# makes four things:
-#
-# =for :list
-# * a page saying "first door opens in X days" the calendar starts
-# * a calendar page on and after the calendar starts
-# * a page for each day in the month with an article
-# * an Atom feed
-#
-# This library was originally written just for RJBS's Perl Advent Calendar, so it
-# assumed you'd always be publishing from Dec 1 to Dec 24 or so.  It has recently
-# been retooled to work across arbitrary ranges, as long as they're within one
-# month.  This feature isn't well tested.  Neither is the rest of the code, to be
-# perfectly honest, though...
-#
-# =head1 OVERVIEW
-#
-# To build an Advent calendar:
-#
-# =for :list
-# 1. create an advent.ini configuration file
-# 2. write articles and put them in a directory
-# 3. schedule F<advcal> to run nightly
-#
-# F<advent.ini> is easy to produce.  Here's the one used for the original RJBS
-# Advent Calendar:
-#
-#   title  = RJBS Advent Calendar
-#   year   = 2009
-#   uri    = http://advent.rjbs.manxome.org/
-#   editor = Ricardo Signes
-#   category = Perl
-#   category = RJBS
-#
-#   article_dir = rjbs/articles
-#   share_dir   = share
-#
-# These should all be self-explanatory.  Only C<category> can be provided more
-# than once, and is used for the category listing in the Atom feed.
-#
-# These settings all correspond to L<calendar attributes/ATTRIBUTES> described
-# below.  A few settings below are not given above.
-#
-# Articles are easy, too.  They're just files in the C<article_dir>.  They begin
-# with an email-like set of headers, followed by a body written in Pod.  For
-# example, here's the beginning of the first article in the original calendar:
-#
-#   Title:  Built in Our Workshop, Delivered in Your Package
-#   Topic: Sub::Exporter
-#
-#   =head1 Exporting
-#
-#   In Perl, we organize our subroutines (and other stuff) into namespaces called
-#   packages.  This makes it easy to avoid having to think of unique names for
-#
-# The two headers seen above, title and topic, are the only headers required,
-# and correspond to those attributes in the L<WWW::AdventCalendar::Article>
-# object created from the article file.
-#
-# Finally, running L<advcal> is easy, too.  Here is its usage:
-#
-#   advcal [-aot] [long options...]
-#     -c --config       the ini file to read for configuration
-#     -a --article-dir  the root of articles
-#     --share-dir       the root of shared files
-#     -o --output-dir   output directory
-#     --today           the day we treat as "today"; default to today
-#
-#     -t --tracker      include Google Analytics; -t TRACKER-ID
-#     -y --year-links   place year links at the bottom of the page
-#
-# Options given on the command line override those loaded form configuration.  By
-# running this program every day, we cause the calendar to be rebuilt, adding any
-# new articles that have become available.
-#
-# =head1 ATTRIBUTES
-#
-# =for :list
-# = title
-# The title of the calendar, to be used in headers, the feed, and so on.
-# = tagline
-# A tagline for the calendar, used in some templates.  Optional.
-# = uri
-# The base URI of the calendar, including trailing slash.
-# = editor
-# The name of the calendar's editor, used in the feed.
-# = default_author
-# The name of the calendar's default author, used for articles that provide none.
-# = year
-# The calendar year.  Optional, if you provide C<start_date> and C<end_date>.
-# = start_date
-# The start of the article-containing period.  Defaults to Dec 1 of the year.
-# = end_date
-# The end of the article-containing period.  Defaults to Dec 24 of the year.
-# = categories
-# An arrayref of category names for use in the feed.
-# = article_dir
-# The directory in which articles can be found, with names like
-# F<YYYY-MM-DD.html>.
-# = share_dir
-# The directory for templates, stylesheets, and other static content.
-# = output_dir
-# The directory into which output files will be written.
-# = today
-# The date to treat as "today" when deciding how much of the calendar to publish.
-# = tracker_id
-# A Google Analytics tracker id.  If given, each page will include analytics.
-#
-# =cut
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a library for producing Advent calendar websites.  In other words, it
+#pod makes four things:
+#pod
+#pod =for :list
+#pod * a page saying "first door opens in X days" the calendar starts
+#pod * a calendar page on and after the calendar starts
+#pod * a page for each day in the month with an article
+#pod * an Atom feed
+#pod
+#pod This library was originally written just for RJBS's Perl Advent Calendar, so it
+#pod assumed you'd always be publishing from Dec 1 to Dec 24 or so.  It has recently
+#pod been retooled to work across arbitrary ranges, as long as they're within one
+#pod month.  This feature isn't well tested.  Neither is the rest of the code, to be
+#pod perfectly honest, though...
+#pod
+#pod =head1 OVERVIEW
+#pod
+#pod To build an Advent calendar:
+#pod
+#pod =for :list
+#pod 1. create an advent.ini configuration file
+#pod 2. write articles and put them in a directory
+#pod 3. schedule F<advcal> to run nightly
+#pod
+#pod F<advent.ini> is easy to produce.  Here's the one used for the original RJBS
+#pod Advent Calendar:
+#pod
+#pod   title  = RJBS Advent Calendar
+#pod   year   = 2009
+#pod   uri    = http://advent.rjbs.manxome.org/
+#pod   editor = Ricardo Signes
+#pod   category = Perl
+#pod   category = RJBS
+#pod
+#pod   article_dir = rjbs/articles
+#pod   share_dir   = share
+#pod
+#pod These should all be self-explanatory.  Only C<category> can be provided more
+#pod than once, and is used for the category listing in the Atom feed.
+#pod
+#pod These settings all correspond to L<calendar attributes/ATTRIBUTES> described
+#pod below.  A few settings below are not given above.
+#pod
+#pod Articles are easy, too.  They're just files in the C<article_dir>.  They begin
+#pod with an email-like set of headers, followed by a body written in Pod.  For
+#pod example, here's the beginning of the first article in the original calendar:
+#pod
+#pod   Title:  Built in Our Workshop, Delivered in Your Package
+#pod   Topic: Sub::Exporter
+#pod
+#pod   =head1 Exporting
+#pod
+#pod   In Perl, we organize our subroutines (and other stuff) into namespaces called
+#pod   packages.  This makes it easy to avoid having to think of unique names for
+#pod
+#pod The two headers seen above, title and topic, are the only headers required,
+#pod and correspond to those attributes in the L<WWW::AdventCalendar::Article>
+#pod object created from the article file.
+#pod
+#pod Finally, running L<advcal> is easy, too.  Here is its usage:
+#pod
+#pod   advcal [-aot] [long options...]
+#pod     -c --config       the ini file to read for configuration
+#pod     -a --article-dir  the root of articles
+#pod     --share-dir       the root of shared files
+#pod     -o --output-dir   output directory
+#pod     --today           the day we treat as "today"; default to today
+#pod
+#pod     -t --tracker      include Google Analytics; -t TRACKER-ID
+#pod     -y --year-links   place year links at the bottom of the page
+#pod
+#pod Options given on the command line override those loaded form configuration.  By
+#pod running this program every day, we cause the calendar to be rebuilt, adding any
+#pod new articles that have become available.
+#pod
+#pod =head1 ATTRIBUTES
+#pod
+#pod =for :list
+#pod = title
+#pod The title of the calendar, to be used in headers, the feed, and so on.
+#pod = tagline
+#pod A tagline for the calendar, used in some templates.  Optional.
+#pod = uri
+#pod The base URI of the calendar, including trailing slash.
+#pod = editor
+#pod The name of the calendar's editor, used in the feed.
+#pod = default_author
+#pod The name of the calendar's default author, used for articles that provide none.
+#pod = year
+#pod The calendar year.  Optional, if you provide C<start_date> and C<end_date>.
+#pod = start_date
+#pod The start of the article-containing period.  Defaults to Dec 1 of the year.
+#pod = end_date
+#pod The end of the article-containing period.  Defaults to Dec 24 of the year.
+#pod = categories
+#pod An arrayref of category names for use in the feed.
+#pod = article_dir
+#pod The directory in which articles can be found, with names like
+#pod F<YYYY-MM-DD.html>.
+#pod = share_dir
+#pod The directory for templates, stylesheets, and other static content.
+#pod = output_dir
+#pod The directory into which output files will be written.
+#pod = today
+#pod The date to treat as "today" when deciding how much of the calendar to publish.
+#pod = tracker_id
+#pod A Google Analytics tracker id.  If given, each page will include analytics.
+#pod
+#pod =cut
 
 has title  => (is => 'ro', required => 1);
 has uri    => (is => 'ro', required => 1);
@@ -274,14 +274,14 @@ sub BUILD {
   }
 }
 
-# =method build
-#
-#   $calendar->build;
-#
-# This method does all the work: it reads in the articles, decides how many to
-# show, writes out the rendered pages, the index, and the atom feed.
-#
-# =cut
+#pod =method build
+#pod
+#pod   $calendar->build;
+#pod
+#pod This method does all the work: it reads in the articles, decides how many to
+#pod show, writes out the rendered pages, the index, and the atom feed.
+#pod
+#pod =cut
 
 my $SCHEMA = Color::Palette::Schema->new({
   required_colors => [ qw(
@@ -482,15 +482,15 @@ sub _w3cdtf {
   DateTime::Format::W3CDTF->new->format_datetime($datetime);
 }
 
-# =method read_articles
-#
-#   my $article = $calendar->read_articles;
-#
-# This method reads in all the articles for the calendar and returns a hashref.
-# The keys are dates (in the format C<YYYY-MM-DD>) and the values are
-# L<WWW::AdventCalendar::Article> objects.
-#
-# =cut
+#pod =method read_articles
+#pod
+#pod   my $article = $calendar->read_articles;
+#pod
+#pod This method reads in all the articles for the calendar and returns a hashref.
+#pod The keys are dates (in the format C<YYYY-MM-DD>) and the values are
+#pod L<WWW::AdventCalendar::Article> objects.
+#pod
+#pod =cut
 
 sub read_articles {
   my ($self) = @_;
@@ -509,11 +509,11 @@ sub read_articles {
     die "no title set in $file\n" unless $document->header('title');
 
     my $article  = WWW::AdventCalendar::Article->new(
-      body   => $document->body,
-      date   => _parse_isodate($isodate),
-      title  => $document->header('title'),
-      topic  => $document->header('topic'),
-      author => $document->header('author')
+      body   => scalar $document->body,
+      date   => scalar _parse_isodate($isodate),
+      title  => scalar $document->header('title'),
+      topic  => scalar $document->header('topic'),
+      author => scalar $document->header('author')
              // scalar $self->default_author,
       calendar => $self,
     );
@@ -543,7 +543,7 @@ WWW::AdventCalendar - a calendar for a month of articles (on the web)
 
 =head1 VERSION
 
-version 1.111
+version 1.112
 
 =head1 DESCRIPTION
 
@@ -731,9 +731,15 @@ A Google Analytics tracker id.  If given, each page will include analytics.
 
 Ricardo SIGNES <rjbs@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Len Jaffe
+
+Len Jaffe <lenjaffe@jaffesystems.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2015 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
